# PERF02-BP01: Select the best compute options

## Description

Evaluate VMs vs containers vs serverless cho workload.

## Implementation Guidance

- Assess workload requirements
- Compare VMs, containers, serverless
- Consider startup time requirements
- Evaluate operational overhead
- Match compute to workload patterns

## Risk Level

Medium - Wrong compute type affects performance and cost.

## Related Best Practices

- [PERF02-BP02](PERF02-BP02-Compute-Configuration-Options.md)
- [PERF02-BP04](PERF02-BP04-Right-Sizing.md)
